@@ -27,9 +27,9 @@ impl Assert {
     let value = extract(&item["assert"], "value");
 
     Assert {
-      name: name.to_string(),
-      key: key.to_string(),
-      value: value.to_string(),
+      name,
+      key,
+      value,
     }
   }
 }
@@ -47,7 +47,7 @@ impl Runnable for Assert {
     let assertion = json!(self.value.to_owned());
 
     if !stored.eq(&assertion) {
-      panic!("Assertion missmatched: {} != {}", stored, assertion);
+      panic!("Assertion mismatched: {} != {}", stored, assertion);
     }
   }
 }
