@@ -6,7 +6,7 @@ pub fn write_file(filepath: &str, content: String) {
   let path = Path::new(filepath);
   let display = path.display();
 
-  let mut file = match File::create(&path) {
+  let mut file = match File::create(path) {
     Err(why) => panic!("couldn't create {}: {:?}", display, why),
     Ok(file) => file,
   };
